#ifndef GRAPH_HPP
#define GRAPH_HPP

#include <vector>

using vertex_id = unsigned int; 

// Represents the input graph to be partitioned
class graph {
public:    

    /** @brief  Initializes the graph to be partitioned
     *  @param  Adjacency lists
     */
    graph(std::vector<std::vector<unsigned int>> a);

    /** @brief  Returns the number of vertices of the graph
     *  @return Number of vertices
     */
    unsigned int num_vertices() const;
    
    /** @brief  Provides access to the adjacency of a vertex  
     *  @param  Vertex Id
     *  @return Adjacency of the vertex
     */
    std::vector<unsigned int> get_adjacency(vertex_id v) const;

private:
    unsigned int vertices_;
	std::vector<std::vector<unsigned int>> adjacency_list_;
};

#endif
